@@ -87,7 +87,7 @@ class AdaptiveHistory:
         Offload old items and reload them on the fly
     """
 
-    __MAX_HISTORY_ITEMS = 10
+    __MAX_HISTORY_ITEMS = 4
 
     def __init__(self):
         """
@@ -418,6 +418,8 @@ class AdaptiveWindow:
             self.set_adaptive(True)
         else:
             self.set_adaptive(False)
+        if width <= Size.PHONE:
+            adaptive_size = AdaptiveSize.PHONE
         if width <= Size.SMALL:
             adaptive_size = AdaptiveSize.SMALL
         elif width <= Size.MEDIUM:
