@@ -14,8 +14,9 @@ from gettext import gettext as _
 import itertools
 
 from lollypop.sqlcursor import SqlCursor
-from lollypop.define import App, Type
-from lollypop.utils import format_artist_name, noaccents
+from lollypop.define import App, Type, StorageType
+from lollypop.utils import get_default_storage_type
+from lollypop.utils import format_artist_name, remove_static
 
 
 class ArtistsDatabase:
@@ -79,20 +80,31 @@ class ArtistsDatabase:
             Get artist id
             @param name as string
             @param mb_artist_id as str
-            @return Artist id as int
+            @return (artist_id as int, name as str)
         """
-        # Special case, id name is fully uppercase, do not use NOCASE
-        # We want to have a different artist
         with SqlCursor(App().db) as sql:
-            query = "SELECT rowid from artists\
+            request = "SELECT rowid, name from artists\
                      WHERE name=?"
             params = [name]
             if mb_artist_id:
-                query += " AND (mb_artist_id=? OR mb_artist_id IS NULL)"
+                request += " AND (mb_artist_id=? OR mb_artist_id IS NULL)"
                 params.append(mb_artist_id)
-            if not name.isupper():
-                query += " COLLATE NOCASE"
-            result = sql.execute(query, params)
+            request += " COLLATE NOCASE"
+            result = sql.execute(request, params)
+            v = result.fetchone()
+            if v is not None:
+                return (v[0], v[1])
+            return (None, None)
+
+    def get_id_for_escaped_string(self, name):
+        """
+            Get artist id
+            @param name as escaped string
+            @return int
+        """
+        with SqlCursor(App().db) as sql:
+            request = "SELECT rowid from artists WHERE sql_escape(name)=?"
+            result = sql.execute(request, (name,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
@@ -115,12 +127,23 @@ class ArtistsDatabase:
                 return v[0]
             return ""
 
+    def set_name(self, artist_id, name):
+        """
+            Set artist name
+            @param artist_id as int
+            @param name as str
+        """
+        with SqlCursor(App().db, True) as sql:
+            sql.execute("UPDATE artists\
+                         SET name=?\
+                         WHERE rowid=?",
+                        (name, artist_id))
+
     def set_mb_artist_id(self, artist_id, mb_artist_id):
         """
             Set MusicBrainz artist id
             @param artist_id as int
             @param mb_artist_id as str
-            @warning: commit needed
         """
         with SqlCursor(App().db, True) as sql:
             sql.execute("UPDATE artists\
@@ -142,110 +165,121 @@ class ArtistsDatabase:
                 return v[0]
             return -1
 
-    def get_albums(self, artist_ids):
+    def has_albums(self, artist_id):
         """
-            Get all availables albums for artists
-            @return Array of id as int
+            Get album for artist id
+            @param artist_id as int
+            @return bool
         """
         with SqlCursor(App().db) as sql:
+            storage_type = get_default_storage_type()
             request = "SELECT DISTINCT albums.rowid\
                        FROM album_artists, albums\
-                       WHERE albums.rowid=album_artists.album_id AND(1=0 "
-            for artist_id in artist_ids:
-                request += "OR album_artists.artist_id=%s " % artist_id
-            request += ") ORDER BY year"
-            result = sql.execute(request)
-            return list(itertools.chain(*result))
-
-    def get_compilations(self, artist_ids):
-        """
-            Get all availables compilations for artist
-            @return Array of id as int
-        """
-        with SqlCursor(App().db) as sql:
-            request = "SELECT DISTINCT albums.rowid FROM albums,\
-                       tracks, track_artists, album_artists\
-                       WHERE track_artists.track_id=tracks.rowid\
-                       AND album_artists.artists_id=%s\
-                       AND album_artists.album_id=albums.rowid\
-                       AND albums.rowid=tracks.album_id AND (1=0 " %\
-                Type.COMPILATIONS
-            for artist_id in artist_ids:
-                request += "OR track_artists.artist_id=%s " % artist_id
-            request += ") ORDER BY albums.year"
-            result = sql.execute(request)
-            return list(itertools.chain(*result))
+                       WHERE albums.rowid=album_artists.album_id\
+                       AND album_artists.artist_id=?\
+                       AND albums.storage_type & ?"
+            result = sql.execute(request, (artist_id, storage_type))
+            return len(list(itertools.chain(*result))) != 0
 
     def get(self, genre_ids=[]):
         """
-            Get all available album artists
+            Get all available artists
             @param genre_ids as [int]
             @return [int, str, str]
         """
+        genre_ids = remove_static(genre_ids)
         if App().settings.get_value("show-artist-sort"):
             select = "artists.rowid, artists.sortname, artists.sortname"
         else:
             select = "artists.rowid, artists.name, artists.sortname"
         with SqlCursor(App().db) as sql:
             result = []
+            storage_type = get_default_storage_type()
             if not genre_ids or genre_ids[0] == Type.ALL:
                 # Only artist that really have an album
                 result = sql.execute(
                     "SELECT DISTINCT %s FROM artists, albums, album_artists\
                                   WHERE album_artists.artist_id=artists.rowid\
                                   AND album_artists.album_id=albums.rowid\
-                                  AND albums.mtime!=0\
+                                  AND albums.storage_type & ?\
                                   ORDER BY artists.sortname\
-                                  COLLATE NOCASE COLLATE LOCALIZED" % select)
+                                  COLLATE NOCASE COLLATE LOCALIZED" % select,
+                    (storage_type,))
             else:
-                genres = tuple(genre_ids)
+                filters = (storage_type,)
+                filters += tuple(genre_ids)
                 request = "SELECT DISTINCT %s\
                            FROM artists, albums, album_genres, album_artists\
                            WHERE artists.rowid=album_artists.artist_id\
                            AND albums.rowid=album_artists.album_id\
-                           AND albums.mtime!=0\
+                           AND albums.storage_type & ?\
                            AND album_genres.album_id=albums.rowid AND ("
                 for genre_id in genre_ids:
                     request += "album_genres.genre_id=? OR "
                 request += "1=0) ORDER BY artists.sortname\
                             COLLATE NOCASE COLLATE LOCALIZED"
-                result = sql.execute(request % select, genres)
+                result = sql.execute(request % select, filters)
             return [(row[0], row[1], row[2]) for row in result]
 
-    def get_all(self, genre_ids=[]):
+    def get_performers(self, genre_ids=[]):
         """
-            Get all available artists
+            Get all available performers
             @param genre_ids as [int]
             @return [int, str, str]
         """
+        genre_ids = remove_static(genre_ids)
         if App().settings.get_value("show-artist-sort"):
             select = "artists.rowid, artists.sortname, artists.sortname"
         else:
             select = "artists.rowid, artists.name, artists.sortname"
         with SqlCursor(App().db) as sql:
             result = []
+            storage_type = get_default_storage_type()
             if not genre_ids or genre_ids[0] == Type.ALL:
                 # Only artist that really have an album
                 result = sql.execute(
                     "SELECT DISTINCT %s FROM artists, track_artists, tracks\
                                   WHERE artists.rowid=track_artists.artist_id\
                                   AND tracks.rowid=track_artists.track_id\
-                                  AND tracks.mtime!=0\
+                                  AND tracks.storage_type & ?\
                                   ORDER BY artists.sortname\
-                                  COLLATE NOCASE COLLATE LOCALIZED" % select)
+                                  COLLATE NOCASE COLLATE LOCALIZED" % select,
+                    (storage_type,))
             else:
-                genres = tuple(genre_ids)
+                filters = (storage_type,)
+                filters += tuple(genre_ids)
                 request = "SELECT DISTINCT %s\
                            FROM artists, tracks, track_genres, track_artists\
                            WHERE artists.rowid=track_artists.artist_id\
                            AND tracks.rowid=track_artists.track_id\
-                           AND tracks.mtime!=0\
+                           AND tracks.storage_type & ?\
                            AND track_genres.track_id=tracks.rowid AND ("
                 for genre_id in genre_ids:
                     request += "track_genres.genre_id=? OR "
                 request += "1=0) ORDER BY artists.sortname\
                             COLLATE NOCASE COLLATE LOCALIZED"
-                result = sql.execute(request % select, genres)
+                result = sql.execute(request % select, filters)
+            return [(row[0], row[1], row[2]) for row in result]
+
+    def get_randoms(self, limit):
+        """
+            Return random artists
+            @param limit as int
+            @return [int, str, str]
+        """
+        with SqlCursor(App().db) as sql:
+            storage_type = get_default_storage_type()
+            request = "SELECT DISTINCT artists.rowid,\
+                                       artists.name,\
+                                       artists.sortname\
+                                  FROM artists, albums, album_artists\
+                                  WHERE album_artists.artist_id=artists.rowid\
+                                  AND album_artists.album_id=albums.rowid\
+                                  AND albums.storage_type & ?\
+                                  AND albums.loved != -1\
+                                  ORDER BY random() LIMIT ?\
+                                  COLLATE NOCASE COLLATE LOCALIZED"
+            result = sql.execute(request, (storage_type, limit))
             return [(row[0], row[1], row[2]) for row in result]
 
     def get_ids(self, genre_ids=[]):
@@ -256,6 +290,7 @@ class ArtistsDatabase:
         """
         with SqlCursor(App().db) as sql:
             result = []
+            storage_type = get_default_storage_type()
             if not genre_ids or genre_ids[0] == Type.ALL:
                 # Only artist that really have an album
                 result = sql.execute(
@@ -263,22 +298,24 @@ class ArtistsDatabase:
                                   FROM artists, albums, album_artists\
                                   WHERE album_artists.artist_id=artists.rowid\
                                   AND album_artists.album_id=albums.rowid\
-                                  AND albums.mtime!=0\
+                                  AND albums.storage_type & ?\
                                   ORDER BY artists.sortname\
-                                  COLLATE NOCASE COLLATE LOCALIZED")
+                                  COLLATE NOCASE COLLATE LOCALIZED",
+                    (storage_type,))
             else:
-                genres = tuple(genre_ids)
+                filters = (storage_type,)
+                filters += tuple(genre_ids)
                 request = "SELECT DISTINCT artists.rowid\
                            FROM artists, albums, album_genres, album_artists\
                            WHERE artists.rowid=album_artists.artist_id\
-                           AND albums.mtime!=0\
+                           AND albums.storage_type & ?\
                            AND albums.rowid=album_artists.album_id\
                            AND album_genres.album_id=albums.rowid AND ("
                 for genre_id in genre_ids:
                     request += "album_genres.genre_id=? OR "
                 request += "1=0) ORDER BY artists.sortname\
                             COLLATE NOCASE COLLATE LOCALIZED"
-                result = sql.execute(request, genres)
+                result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
     def exists(self, artist_id):
@@ -294,25 +331,6 @@ class ArtistsDatabase:
                 return bool(v[0])
             return False
 
-    def search(self, searched):
-        """
-            Search for artists looking like string
-            @param searched as str
-            @return [int]
-        """
-        no_accents = noaccents(searched)
-        with SqlCursor(App().db) as sql:
-            items = []
-            for filter in [(no_accents + "%",),
-                           ("%" + no_accents,),
-                           ("%" + no_accents + "%",)]:
-                request = "SELECT artists.rowid\
-                           FROM artists, albums, album_artists\
-                           WHERE noaccents(artists.name) LIKE ? LIMIT 25"
-                result = sql.execute(request, filter)
-                items += list(itertools.chain(*result))
-            return items
-
     def count(self):
         """
             Count artists
@@ -323,17 +341,19 @@ class ArtistsDatabase:
                                   FROM artists, album_artists, albums\
                                   WHERE album_artists.album_id=albums.rowid\
                                   AND artists.rowid=album_artists.artist_id\
-                                  AND albums.mtime!=0")
+                                  AND albums.storage_type & ?",
+                                 (StorageType.COLLECTION | StorageType.SAVED,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
             return 0
 
-    def clean(self):
+    def clean(self, commit=True):
         """
             Clean artists
+            @param commit as bool
         """
-        with SqlCursor(App().db, True) as sql:
+        with SqlCursor(App().db, commit) as sql:
             sql.execute("DELETE FROM artists WHERE artists.rowid NOT IN (\
                             SELECT album_artists.artist_id\
                             FROM album_artists) AND artists.rowid NOT IN (\
