@@ -77,17 +77,19 @@ class ArtBehaviour:
 class ViewType:
     DEFAULT = 1 << 0
     TWO_COLUMNS = 1 << 1
-    DND = 1 << 2
-    SEARCH = 1 << 3
-    PLAYLISTS = 1 << 4
-    ALBUM = 1 << 5
-    SMALL = 1 << 6
-    ADAPTIVE = 1 << 7
-    SCROLLED = 1 << 8
-    OVERLAY = 1 << 9
-    FULLSCREEN = 1 << 10
-    PLAYBACK = 1 << 11
-    BANNER = 1 << 12
+    SINGLE_COLUMN = 1 << 2
+    DND = 1 << 3
+    SEARCH = 1 << 4
+    PLAYLISTS = 1 << 5
+    ALBUM = 1 << 6
+    SMALL = 1 << 7
+    ADAPTIVE = 1 << 8
+    SCROLLED = 1 << 9
+    OVERLAY = 1 << 10
+    FULLSCREEN = 1 << 11
+    PLAYBACK = 1 << 12
+    BANNER = 1 << 13
+    ARTIST = 1 << 14
 
 
 NetworkAccessACL = {
@@ -111,8 +113,9 @@ NetworkAccessACL = {
 
 class LoadingState:
     NONE = 0
-    ABORTED = 1
-    FINISHED = 2
+    RUNNING = 1
+    ABORTED = 2
+    FINISHED = 3
 
 
 class IndicatorType:
@@ -124,10 +127,10 @@ class IndicatorType:
 
 
 class ArtSize:
-    SMALL = 50
+    SMALL = 50     # Depends on cover-size in gsettings
     MEDIUM = 100
-    BANNER = 150
-    BIG = 200
+    BANNER = 150   # Depends on cover-size in gsettings
+    BIG = 200      # Depends on cover-size in gsettings
     MINIPLAYER = 300
     FULLSCREEN = 400
     MPRIS = 900
@@ -139,6 +142,12 @@ class ScanType:
     FULL = 2
 
 
+class ScanUpdate:
+    ADDED = 0
+    REMOVED = 1
+    MODIFIED = 2
+
+
 class SelectionListMask:
     NONE = 1 << 0
     SIDEBAR = 1 << 1
@@ -164,19 +173,27 @@ class PowerManagement:
     BOTH = 3             # Inhibit screensaver and suspend
 
 
+class ReplayGain:
+    NONE = 0
+    TRACK = 1
+    ALBUM = 1
+
+
 class AdaptiveSize:
     NONE = 1 << 0
-    SMALL = 1 << 1
-    MEDIUM = 1 << 2
-    NORMAL = 1 << 3
-    BIG = 1 << 4
-    LARGE = 1 << 5
+    PHONE = 1 << 1
+    SMALL = 1 << 2
+    MEDIUM = 1 << 3
+    NORMAL = 1 << 4
+    BIG = 1 << 5
+    LARGE = 1 << 6
 
 
 class Size:
     MINI = 250
-    SMALL = 400
-    MEDIUM = 720  # Librem Phone
+    PHONE = 360  # Librem Phone
+    SMALL = 500
+    MEDIUM = 720
     NORMAL = 1000
     BIG = 1300
 
@@ -198,7 +215,7 @@ class Type:
     RANDOMS = -4
     RECENTS = -5
     LOVED = -6
-    NEVER = -7
+    LITTLE = -7
     ALL = -8
     # WEB is stored in DB, can't be changed
     WEB = -9
@@ -243,17 +260,3 @@ SPOTIFY_CLIENT_ID = "0b144843878a46b2b12e0958c342c3ac"
 SPOTIFY_SECRET = "265ab8e057684f1b9e69e0c58f4881c1"
 AUDIODB_CLIENT_ID = "195003"
 FANARTTV_ID = "1cb10bc910c8d4fc34e0c78ac4e8ef46"
-
-
-STATIC_ALBUM_NAME = {
-    Type.POPULARS: "Popular albums",
-    Type.RANDOMS: "Random albums",
-    Type.LOVED: "Loved albums",
-    Type.RECENTS: "Recently added albums",
-    Type.NEVER: "Unplayed albums",
-    Type.PLAYLISTS: "Playlists",
-    Type.RADIOS: "Radios",
-    Type.YEARS: "Years",
-    Type.ALL: "All albums",
-    Type.COMPILATIONS: "Compilations"
-}
