@@ -10,8 +10,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from gi.repository import GLib
+
+from pickle import load, dump
+
 from lollypop.helper_web_youtube import YouTubeHelper
-from lollypop.define import App
+from lollypop.helper_web_invidious import InvidiousHelper
+from lollypop.define import CACHE_PATH, App
+from lollypop.logger import Logger
 
 
 class WebHelper:
@@ -23,7 +29,10 @@ class WebHelper:
         """
             Init helper
         """
-        self.__helpers = [YouTubeHelper()]
+        if App().settings.get_value("invidious-server").get_string():
+            self.__helpers = [InvidiousHelper()]
+        else:
+            self.__helpers = [YouTubeHelper()]
 
     def set_uri(self, track, cancellable):
         """
@@ -31,14 +40,28 @@ class WebHelper:
             @param track as Track
             @param cancellable as Gio.Cancellable
         """
-        if track.is_http:
+        escaped = GLib.uri_escape_string(track.uri, None, True)
+        # Read URI from cache
+        try:
+            uri = load(open("%s/web_%s" % (CACHE_PATH, escaped), "rb"))
+            track.set_uri(uri)
             return
+        except:
+            pass
+
+        # Get URI from helpers
         for helper in self.__helpers:
             uri = helper.get_uri(track, cancellable)
             if uri:
-                App().tracks.set_uri(track.id, uri)
+                Logger.info("Track found by %s" % helper)
+                try:
+                    # CACHE URI
+                    with open("%s/web_%s" % (CACHE_PATH, escaped), "wb") as f:
+                        dump(uri, f)
+                except:
+                    pass
                 track.set_uri(uri)
-                return
+                break
 
     def get_track_content(self, track):
         """
@@ -49,5 +72,6 @@ class WebHelper:
         for helper in self.__helpers:
             uri = helper.get_uri_content(track)
             if uri:
+                Logger.info("Track URI found by %s" % helper)
                 return uri
-        return ""
+        return None
