@@ -16,7 +16,8 @@ import json
 from re import sub
 
 from lollypop.define import App, GOOGLE_API_ID
-from lollypop.utils import escape
+from lollypop.utils import get_network_available, get_page_score
+from lollypop.utils import get_youtube_dl
 from lollypop.logger import Logger
 
 
@@ -31,7 +32,7 @@ class YouTubeHelper:
         """
             Init heApper
         """
-        self.__fallback = False
+        pass
 
     def get_uri(self, track, cancellable):
         """
@@ -40,11 +41,11 @@ class YouTubeHelper:
             @return uri as str
             @param cancellable as Gio.Cancellable
         """
-        yid = self.__get_youtube_id(track, cancellable)
-        if yid is None:
+        youtube_id = self.__get_youtube_id(track, cancellable)
+        if youtube_id is None:
             return ""
         else:
-            return "https://www.youtube.com/watch?v=%s" % yid
+            return "https://www.youtube.com/watch?v=%s" % youtube_id
 
     def get_uri_content(self, track):
         """
@@ -52,23 +53,32 @@ class YouTubeHelper:
             @param track as Track
             @return content uri as str/None
         """
-        # Remove playlist args
-        uri = sub("list=.*", "", track.uri)
-        argv_list = [
-            ["youtube-dl", "-g", "-f", "bestaudio", uri, None],
-            ["youtube-dl", "-g", uri, None]]
-        for argv in argv_list:
-            (s, o, e, s) = GLib.spawn_sync(None,
-                                           argv,
-                                           None,
-                                           GLib.SpawnFlags.SEARCH_PATH,
-                                           None)
-            if o:
-                return o.decode("utf-8")
-        error = e.decode("utf-8")
-        if App().notify is not None:
-            App().notify.send(error)
-        Logger.warning("YouTubeHelper::get_uri_content(): %s", error)
+        try:
+            proxy = GLib.environ_getenv(GLib.get_environ(), "all_proxy")
+            if proxy is not None and proxy.startswith("socks://"):
+                proxy = proxy.replace("socks://", "socks4://")
+            (path, env) = get_youtube_dl()
+            # Remove playlist args
+            uri = sub("list=.*", "", track.uri)
+            argv_list = [
+                [path, "-g", "-f", "bestaudio", uri],
+                [path, "-g", uri]]
+            for argv in argv_list:
+                if proxy is not None:
+                    argv += ["--proxy", proxy, None]
+                else:
+                    argv.append(None)
+                (s, o, e, s) = GLib.spawn_sync(None,
+                                               argv,
+                                               env,
+                                               GLib.SpawnFlags.SEARCH_PATH,
+                                               None)
+                if o:
+                    return o.decode("utf-8")
+            error = e.decode("utf-8")
+            Logger.warning("YouTubeHelper::get_uri_content(): %s", error)
+        except Exception as e:
+            Logger.warning("YouTubeHelper::get_uri_content(): %s", e)
         return None
 
 #######################
@@ -81,8 +91,6 @@ class YouTubeHelper:
             @param cancellable as Gio.Cancellable
             @return youtube id as str
         """
-        if self.__fallback:
-            return self.__get_youtube_id_fallback(track, cancellable)
         unescaped = "%s %s" % (track.artists[0],
                                track.name)
         search = GLib.uri_escape_string(
@@ -90,6 +98,7 @@ class YouTubeHelper:
                             None,
                             True)
         key = App().settings.get_value("cs-api-key").get_string()
+        data = b""
         try:
             uri = "https://www.googleapis.com/youtube/v3/" +\
                   "search?part=snippet&q=%s&" % search +\
@@ -101,54 +110,31 @@ class YouTubeHelper:
                 dic = {}
                 best = self.__BAD_SCORE
                 for i in decode["items"]:
-                    score = self.__get_youtube_score(i["snippet"]["title"],
-                                                     track.name,
-                                                     track.artists[0],
-                                                     track.album.name)
-                    if score < best:
+                    score = get_page_score(i["snippet"]["title"],
+                                           track.name,
+                                           track.artists[0],
+                                           track.album.name)
+                    if score == -1 or score == best:
+                        continue
+                    elif score < best:
                         best = score
-                    elif score == best:
-                        continue  # Keep first result
                     dic[score] = i["id"]["videoId"]
                 # Return url from first dic item
-                if best == self.__BAD_SCORE:
+                if best == 10000000:
                     return None
                 else:
                     return dic[best]
-        except Exception as e:
-            Logger.warning("YouTubeHelper::__get_youtube_id(): %s", e)
-            self.__fallback = True
-            return self.__get_youtube_id_fallback(track, cancellable)
+        except:
+            Logger.warning("YouTubeHelper::__get_youtube_id(): %s", data)
+            if get_network_available("STARTPAGE"):
+                return self.__get_youtube_id_start(track, cancellable)
+            elif get_network_available("DUCKDUCKGO"):
+                return self.__get_youtube_id_duckduck(track, cancellable)
         return None
 
-    def __get_youtube_score(self, page_title, title, artist, album):
+    def __get_youtube_id_start(self, track, cancellable):
         """
-            Calculate youtube score
-            if page_title looks like (title, artist, album), score is lower
-            @return int
-        """
-        page_title = escape(page_title.lower(), [])
-        artist = escape(artist.lower(), [])
-        album = escape(album.lower(), [])
-        title = escape(title.lower(), [])
-        # YouTube page title should be at least as long as wanted title
-        if len(page_title) < len(title):
-            return self.__BAD_SCORE
-        # Remove common word for a valid track
-        page_title = page_title.replace("official", "")
-        page_title = page_title.replace("video", "")
-        page_title = page_title.replace("audio", "")
-        # Remove artist name
-        page_title = page_title.replace(artist, "")
-        # Remove album name
-        page_title = page_title.replace(album, "")
-        # Remove title
-        page_title = page_title.replace(title, "")
-        return len(page_title)
-
-    def __get_youtube_id_fallback(self, track, cancellable):
-        """
-            Get youtube id (fallback)
+            Get youtube id via startpage
             @param track as Track
             @param cancellable as Gio.Cancellable
             @return youtube id as str
@@ -165,7 +151,7 @@ class YouTubeHelper:
                             unescaped.replace(" ", "+"),
                             None,
                             True)
-            uri = "https://www.youtube.com/results?search_query=%s" % search
+            uri = "https://www.startpage.com/do/search?query=%s" % search
             (status, data) = App().task_helper.load_uri_content_sync(
                 uri, cancellable)
             if not status:
@@ -176,19 +162,17 @@ class YouTubeHelper:
             ytems = []
             for link in soup.findAll("a"):
                 href = link.get("href")
-                title = link.get("title")
-                if href is None or title is None:
+                title = link.get_text()
+                if href is None or title is None or\
+                        href.find("youtube.com/watch?v") == -1:
                     continue
-                if href.startswith("/watch?v="):
-                    href = href.replace("/watch?v=", "")
-                    ytems.append((href, title))
+                youtube_id = href.split("watch?v=")[1]
+                ytems.append((youtube_id, title))
             dic = {}
             best = self.__BAD_SCORE
             for (yid, title) in ytems:
-                score = self.__get_youtube_score(title,
-                                                 track.name,
-                                                 track.artists[0],
-                                                 track.album.name)
+                score = get_page_score(title, track.name,
+                                       track.artists[0], track.album.name)
                 if score < best:
                     best = score
                 elif score == best:
@@ -200,6 +184,60 @@ class YouTubeHelper:
             else:
                 return dic[best]
         except Exception as e:
-            Logger.warning("YouTubeHelper::__get_youtube_id_fallback(): %s", e)
-            self.__fallback = True
+            Logger.warning("YouTubeHelper::__get_youtube_id_start(): %s", e)
+        return None
+
+    def __get_youtube_id_duckduck(self, track, cancellable):
+        """
+            Get youtube id via duckduckgo
+            @param track as Track
+            @param cancellable as Gio.Cancellable
+            @return youtube id as str
+        """
+        try:
+            from bs4 import BeautifulSoup
+        except:
+            print("$ sudo pip3 install beautifulsoup4")
+            return None
+        try:
+            unescaped = "%s %s" % (track.artists[0],
+                                   track.name)
+            search = GLib.uri_escape_string(
+                            unescaped.replace(" ", "+"),
+                            None,
+                            True)
+            uri = "https://duckduckgo.com/lite/?q=%s" % search
+            (status, data) = App().task_helper.load_uri_content_sync(
+                uri, cancellable)
+            if not status:
+                return None
+
+            html = data.decode("utf-8")
+            soup = BeautifulSoup(html, "html.parser")
+            ytems = []
+            for link in soup.findAll("a"):
+                href = GLib.uri_unescape_string(link.get("href"), None)
+                title = link.get_text()
+                if href is None or title is None or\
+                        href.find("youtube.com/watch?v") == -1:
+                    continue
+                youtube_id = href.split("watch?v=")[1]
+                ytems.append((youtube_id, title))
+            dic = {}
+            best = self.__BAD_SCORE
+            for (yid, title) in ytems:
+                score = get_page_score(title, track.name,
+                                       track.artists[0], track.album.name)
+                if score < best:
+                    best = score
+                elif score == best:
+                    continue  # Keep first result
+                dic[score] = yid
+            # Return url from first dic item
+            if best == self.__BAD_SCORE:
+                return None
+            else:
+                return dic[best]
+        except Exception as e:
+            Logger.warning("YouTubeHelper::__get_youtube_id_duckduck(): %s", e)
         return None
