@@ -12,7 +12,7 @@
 
 import gi
 gi.require_version("Secret", "1")
-from gi.repository import Gio, GLib, GObject
+from gi.repository import Gio, GLib
 
 from gettext import gettext as _
 
@@ -30,38 +30,26 @@ from pickle import load, dump
 import re
 
 from lollypop.define import App, LOLLYPOP_DATA_PATH
-from lollypop.objects import Track
+from lollypop.objects_track import Track
 from lollypop.utils import get_network_available
 from lollypop.logger import Logger
 from lollypop.goa import GoaSyncedAccount
 
 
-class LastFM(GObject.Object, LastFMNetwork, LibreFMNetwork):
+class LastFMBase:
     """
-       Lastfm:
-       We recommend you don"t distribute the API key and secret with your app,
-       and that you ask users who want to build it to apply for a key of
-       their own. We don"t believe that this would violate the terms of most
-       open-source licenses.
-       That said, we can"t stop you from distributing the key and secret if you
-       want, and if your app isn"t written in a compiled language, you don"t
-       really have much option :).
+       Base class for LastFM/LibreFM
     """
-    __gsignals__ = {
-        "new-artist": (GObject.SignalFlags.RUN_FIRST, None, (str, str)),
-    }
 
     def __init__(self, name):
         """
             Init lastfm support
             @param name as str
         """
-        GObject.Object.__init__(self)
         self.__name = name
         self.__login = ""
         self.session_key = ""
         self.__password = None
-        self.__goa = None
         self.__queue_id = None
         try:
             self.__queue = load(
@@ -69,45 +57,23 @@ class LastFM(GObject.Object, LastFMNetwork, LibreFMNetwork):
         except Exception as e:
             Logger.info("LastFM::__init__(): %s", e)
             self.__queue = []
-        if name == "librefm":
-            LibreFMNetwork.__init__(self)
-            Logger.debug("LibreFMNetwork.__init__()")
-        else:
-            self.__goa = GoaSyncedAccount("Last.fm")
-            self.__goa.connect("account-switched",
-                               self.on_goa_account_switched)
-            if self.is_goa:
-                Logger.debug("LastFMNetwork.__init__(goa.)")
-                auth = self.__goa.oauth2_based
-                self.__API_KEY = auth.props.client_id
-                self.__API_SECRET = auth.props.client_secret
-            else:
-                Logger.debug("LastFMNetwork.__init__(secret)")
-                self.__API_KEY = "7a9619a850ccf7377c46cf233c51e3c6"
-                self.__API_SECRET = "9254319364d73bec6c59ace485a95c98"
-            LastFMNetwork.__init__(self,
-                                   api_key=self.__API_KEY,
-                                   api_secret=self.__API_SECRET)
-        self.connect()
+        self.connect_service()
         Gio.NetworkMonitor.get_default().connect("notify::network-available",
                                                  self.__on_network_available)
 
-    def connect(self, full_sync=False, callback=None, *args):
+    def connect_service(self, full_sync=False, callback=None, *args):
         """
             Connect service
             @param full_sync as bool
             @param callback as function
         """
-        if self.is_goa:
-            App().task_helper.run(self.__connect, full_sync)
-        else:
-            from lollypop.helper_passwords import PasswordsHelper
-            helper = PasswordsHelper()
-            helper.get(self.__name,
-                       self.__on_get_password,
-                       full_sync,
-                       callback,
-                       *args)
+        from lollypop.helper_passwords import PasswordsHelper
+        helper = PasswordsHelper()
+        helper.get(self.__name,
+                   self.__on_get_password,
+                   full_sync,
+                   callback,
+                   *args)
 
     def save(self):
         """
@@ -220,46 +186,23 @@ class LastFM(GObject.Object, LastFMNetwork, LibreFMNetwork):
             Search similar artists
             @param artist as str
             @param cancellable as Gio.Cancellable
-            @return [str]
+            @return [(str, str)] : list of (artist, cover_uri)
         """
         artists = []
         try:
             artist_item = self.get_artist(artist)
-            for similar_item in artist_item.get_similar():
+            for similar_item in artist_item.get_similar(10):
                 if cancellable.is_cancelled():
                     raise Exception("cancelled")
-                artists.append(similar_item.item.name)
+                artists.append((None,
+                                similar_item.item.name,
+                                similar_item.item.get_cover_image()))
         except Exception as e:
             Logger.error("LastFM::get_similar_artists(): %s", e)
         return artists
 
-    def search_similar_artists(self, artist, cancellable):
-        """
-            Search similar artists
-            @param artist as str
-            @param cancellable as Gio.Cancellable
-        """
-        try:
-            found = False
-            artist_item = self.get_artist(artist)
-            for similar_item in artist_item.get_similar():
-                if cancellable.is_cancelled():
-                    raise Exception("cancelled")
-                found = True
-                artist_name = similar_item.item.name
-                cover_uri = similar_item.item.get_cover_image()
-                GLib.idle_add(self.emit, "new-artist", artist_name, cover_uri)
-        except Exception as e:
-            Logger.error("LastFM::search_similar_artists(): %s", e)
-        if not found:
-            GLib.idle_add(self.emit, "new-artist", None, None)
-
-    def on_goa_account_switched(self, obj):
-        """
-            Callback for GoaSyncedAccount signal "account-switched"
-            @param obj as GoaSyncedAccount
-        """
-        self.connect()
+    def get_artist_id(self, artist_name, cancellable):
+        return artist_name
 
     def set_loved(self, track, loved):
         """
@@ -273,35 +216,29 @@ class LastFM(GObject.Object, LastFMNetwork, LibreFMNetwork):
             else:
                 self.unlove(",".join(track.artists), track.name)
 
-    @property
-    def can_love(self):
-        """
-            True if engine can love
-            @return bool
-        """
-        return True
-
     @property
     def is_goa(self):
         """
-            True if using Gnome Online Account
-        """
-        return self.__goa is not None and self.__goa.has_account
-
-    @property
-    def available(self):
-        """
-            Return True if Last.fm/Libre.fm submission is available
+            True if service is using GOA
             @return bool
         """
-        if not self.session_key:
-            return False
-        if self.is_goa:
-            music_disabled = self.__goa.account.props.music_disabled
-            Logger.debug("Last.fm GOA scrobbling disabled: %s" %
-                         music_disabled)
-            return not music_disabled
-        return True
+        return False
+
+    @property
+    def can_love(self):
+        """
+            True if service can love tracks
+            @return bool
+        """
+        return False
+
+    @property
+    def service_name(self):
+        """
+            Get service name
+            @return str
+        """
+        return self.__name
 
 #######################
 # PRIVATE             #
@@ -320,32 +257,20 @@ class LastFM(GObject.Object, LastFMNetwork, LibreFMNetwork):
         if self.__queue_id is None:
             self.__queue_id = GLib.timeout_add(1000, queue)
 
-    def __connect(self, full_sync=False):
+    def _connect(self, full_sync=False):
         """
             Connect service
             @param full_sync as bool
             @thread safe
         """
-        if not get_network_available("LASTFM"):
-            return
         try:
             self.session_key = ""
-            if self.is_goa:
-                auth = self.__goa.oauth2_based
-                self.api_key = auth.props.client_id
-                self.api_secret = auth.props.client_secret
-                self.session_key = auth.call_get_access_token_sync(None)[0]
-            else:
-                skg = SessionKeyGenerator(self)
-                self.session_key = skg.get_session_key(
-                    username=self.__login,
-                    password_hash=md5(self.__password))
-            if full_sync:
-                App().task_helper.run(self.__populate_loved_tracks)
-            track = App().player.current_track
-            self.playing_now(track)
+            skg = SessionKeyGenerator(self)
+            self.session_key = skg.get_session_key(
+                username=self.__login,
+                password_hash=md5(self.__password))
         except Exception as e:
-            Logger.debug("LastFM::__connect(): %s" % e)
+            Logger.debug("LastFM::_connect(): %s" % e)
 
     def __listen(self, artist, album, title, timestamp, mb_track_id):
         """
@@ -434,7 +359,7 @@ class LastFM(GObject.Object, LastFMNetwork, LibreFMNetwork):
         self.__login = attributes["login"]
         self.__password = password
         if get_network_available("LASTFM"):
-            App().task_helper.run(self.__connect, full_sync,
+            App().task_helper.run(self._connect, full_sync,
                                   callback=(callback, *args))
 
     def __on_network_available(self, monitor, spec):
@@ -445,4 +370,150 @@ class LastFM(GObject.Object, LastFMNetwork, LibreFMNetwork):
         """
         value = monitor.get_property("network-available")
         if value and not self.available:
-            self.connect()
+            self.connect_service()
+
+
+class LibreFM(LastFMBase, LibreFMNetwork):
+    """
+        LibreFM
+    """
+    def __init__(self):
+        """
+            Init LibreFM
+        """
+        LibreFMNetwork.__init__(self)
+        LastFMBase.__init__(self, "librefm")
+        Logger.debug("LibreFMNetwork.__init__()")
+
+    @property
+    def available(self):
+        """
+            Return True if submission is available
+            @return bool
+        """
+        return self.session_key != ""
+
+#######################
+# PRIVATE             #
+#######################
+    def _connect(self, full_sync=False):
+        """
+            Connect service
+            @param full_sync as bool
+            @thread safe
+        """
+        if not get_network_available("LASTFM"):
+            return
+        try:
+            LastFMBase._connect(self, full_sync)
+            self.playing_now(App().player.current_track)
+        except Exception as e:
+            Logger.debug("LastFM::_connect(): %s" % e)
+
+
+class LastFM(LastFMBase, LastFMNetwork):
+    """
+        LastFM
+       We recommend you don"t distribute the API key and secret with your app,
+       and that you ask users who want to build it to apply for a key of
+       their own. We don"t believe that this would violate the terms of most
+       open-source licenses.
+       That said, we can"t stop you from distributing the key and secret if you
+       want, and if your app isn"t written in a compiled language, you don"t
+       really have much option :).
+    """
+    def __init__(self):
+        """
+            Init LastFM
+        """
+        self.__goa = GoaSyncedAccount("Last.fm")
+        self.__goa.connect("account-switched",
+                           self.__on_goa_account_switched)
+        if self.is_goa:
+            Logger.debug("LastFMNetwork.__init__(goa.)")
+            auth = self.__goa.oauth2_based
+            self.__API_KEY = auth.props.client_id
+            self.__API_SECRET = auth.props.client_secret
+        else:
+            Logger.debug("LastFMNetwork.__init__(secret)")
+            self.__API_KEY = "7a9619a850ccf7377c46cf233c51e3c6"
+            self.__API_SECRET = "9254319364d73bec6c59ace485a95c98"
+        LastFMNetwork.__init__(self,
+                               api_key=self.__API_KEY,
+                               api_secret=self.__API_SECRET)
+        LastFMBase.__init__(self, "lastfm")
+
+    def connect_service(self, full_sync=False, callback=None, *args):
+        """
+            Connect service
+            @param full_sync as bool
+            @param callback as function
+        """
+        if self.is_goa:
+            App().task_helper.run(self._connect, full_sync)
+        else:
+            LastFMBase.connect_service(self, full_sync, callback, *args)
+
+    @property
+    def available(self):
+        """
+            Return True if submission is available
+            @return bool
+        """
+        if not self.session_key:
+            return False
+        if self.is_goa:
+            music_disabled = self.__goa.account.props.music_disabled
+            Logger.debug("Last.fm GOA scrobbling disabled: %s" %
+                         music_disabled)
+            return not music_disabled
+        return True
+
+    @property
+    def is_goa(self):
+        """
+            True if service is using GOA
+            @return bool
+        """
+        return self.__goa.has_account
+
+    @property
+    def can_love(self):
+        """
+            True if service can love tracks
+            @return bool
+        """
+        return True
+
+#######################
+# PRIVATE             #
+#######################
+    def _connect(self, full_sync=False):
+        """
+            Connect service
+            @param full_sync as bool
+            @thread safe
+        """
+        if not get_network_available("LASTFM"):
+            return
+        try:
+            if self.is_goa:
+                self.session_key = ""
+                auth = self.__goa.oauth2_based
+                self.api_key = auth.props.client_id
+                self.api_secret = auth.props.client_secret
+                self.session_key = auth.call_get_access_token_sync(None)[0]
+            else:
+                LastFMBase._connect(self, full_sync)
+            if full_sync:
+                App().task_helper.run(self.__populate_loved_tracks)
+            self.playing_now(App().player.current_track)
+        except Exception as e:
+            Logger.debug("LastFM::_connect(): %s" % e)
+
+    def __on_goa_account_switched(self, obj):
+        """
+            Callback for GoaSyncedAccount signal "account-switched"
+            @param obj as GoaSyncedAccount
+        """
+        self.connect_service()
