@@ -20,6 +20,62 @@ from lollypop.objects_track import Track
 from lollypop.objects_album import Album
 
 
+class PlaybackMenu(Gio.Menu):
+    """
+        Menu for playback section (current albums)
+    """
+
+    def __init__(self):
+        """
+            Init menu
+        """
+        Gio.Menu.__init__(self)
+        menu = Gio.Menu()
+        save_playback_action = Gio.SimpleAction.new(name="save_playback")
+        save_playback_action.connect(
+            "activate", self.__on_save_playback_action_activate)
+        App().add_action(save_playback_action)
+        menu.append(_("Create a new playlist"), "app.save_playback")
+        show_track_number_action = Gio.SimpleAction.new_stateful(
+                "show_track_number",
+                None,
+                GLib.Variant.new_boolean(
+                    App().settings.get_value("show-tag-tracknumber")))
+        App().add_action(show_track_number_action)
+        show_track_number_action.connect(
+            "change-state", self.__on_show_track_number_change_state)
+        menu.append(_("Show tracks number"), "app.show_track_number")
+        self.append_section(_("Playing albums"), menu)
+
+    def __on_show_track_number_change_state(self, action, variant):
+        """
+            Update settings and reload view
+            @param Gio.SimpleAction
+            @param GLib.Variant
+        """
+        action.set_state(variant)
+        App().settings.set_value("show-tag-tracknumber", variant)
+        App().window.container.reload_view()
+
+    def __on_save_playback_action_activate(self, action, variant):
+        """
+            Create a new playlist based on current playback
+            @param Gio.SimpleAction
+            @param GLib.Variant
+        """
+        def albums_to_playlist():
+            tracks = []
+            for album in App().player.albums:
+                tracks += album.tracks
+            if tracks:
+                import datetime
+                now = datetime.datetime.now()
+                date_string = now.strftime("%Y-%m-%d-%H:%M:%S")
+                playlist_id = App().playlists.add(date_string)
+                App().playlists.add_tracks(playlist_id, tracks)
+        App().task_helper.run(albums_to_playlist)
+
+
 class BasePlaybackMenu(Gio.Menu):
     """
         Base class for playback menu
@@ -209,10 +265,7 @@ class GenrePlaybackMenu(BasePlaybackMenu):
             @param GLib.Variant
         """
         album_ids = self.__get_album_ids()
-        for album_id in album_ids:
-            album = Album(album_id)
-            App().player.add_album(album)
-        App().player.update_next_prev()
+        App().player.add_album_ids(album_ids)
 
     def _remove_from_playback(self, action, variant):
         """
@@ -221,9 +274,7 @@ class GenrePlaybackMenu(BasePlaybackMenu):
             @param GLib.Variant
         """
         album_ids = self.__get_album_ids()
-        for album_id in album_ids:
-            App().player.remove_album_by_id(album_id)
-        App().player.update_next_prev()
+        App().player.remove_album_by_ids(album_ids)
 
 #######################
 # PRIVATE             #
@@ -288,10 +339,7 @@ class DecadePlaybackMenu(BasePlaybackMenu):
             @param GLib.Variant
         """
         album_ids = self.__get_album_ids()
-        for album_id in album_ids:
-            album = Album(album_id)
-            App().player.add_album(album)
-        App().player.update_next_prev()
+        App().player.add_album_ids(album_ids)
 
     def _remove_from_playback(self, action, variant):
         """
@@ -300,9 +348,7 @@ class DecadePlaybackMenu(BasePlaybackMenu):
             @param GLib.Variant
         """
         album_ids = self.__get_album_ids()
-        for album_id in album_ids:
-            App().player.remove_album_by_id(album_id)
-        App().player.update_next_prev()
+        App().player.remove_album_by_ids(album_ids)
 
 #######################
 # PRIVATE             #
@@ -368,7 +414,6 @@ class AlbumPlaybackMenu(BasePlaybackMenu):
             @param GLib.Variant
         """
         App().player.add_album(self.__album)
-        App().player.update_next_prev()
 
     def _remove_from_playback(self, action, variant):
         """
@@ -377,7 +422,6 @@ class AlbumPlaybackMenu(BasePlaybackMenu):
             @param GLib.Variant
         """
         App().player.remove_album_by_id(self.__album.id)
-        App().player.update_next_prev()
 
 #######################
 # PRIVATE             #
