@@ -19,8 +19,9 @@ from gi.repository import Gio, Gst, GLib, Gtk
 from random import randint
 
 from lollypop.logger import Logger
-from lollypop.define import App, ArtSize, Type, Shuffle, Repeat
-from lollypop.objects import Track
+from lollypop.define import App, ArtSize, Repeat, Notifications
+from lollypop.objects_track import Track
+from lollypop.objects_radio import Radio
 
 
 class Server:
@@ -177,14 +178,6 @@ class MPRIS(Server):
         self.__metadata = {"mpris:trackid": GLib.Variant(
             "o",
             "/org/mpris/MediaPlayer2/TrackList/NoTrack")}
-        # Get the shuffle state for our shuffle toggle setting so we can
-        # remember the last non-NONE suffle state if we start with Shuffle.NONE
-        # then our "on" setting starts with Shuffle.TRACKS.
-        shuffle_state = App().settings.get_enum("shuffle")
-        if shuffle_state != Shuffle.NONE:
-            self.__shuffle_state = shuffle_state
-        else:
-            self.__shuffle_state = Shuffle.TRACKS
         self.__track_id = self.__get_media_id(0)
         self.__bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
         Gio.bus_own_name_on_connection(self.__bus,
@@ -209,9 +202,13 @@ class MPRIS(Server):
 
     def Next(self):
         App().player.next()
+        if App().settings.get_enum("notifications") == Notifications.MPRIS:
+            App().notify.send_track(App().player.current_track)
 
     def Previous(self):
         App().player.prev()
+        if App().settings.get_enum("notifications") == Notifications.MPRIS:
+            App().notify.send_track(App().player.current_track)
 
     def Pause(self):
         App().player.pause()
@@ -261,9 +258,7 @@ class MPRIS(Server):
         elif property_name == "HasTrackList":
             return GLib.Variant("b", False)
         elif property_name == "Shuffle":
-            return GLib.Variant(
-                "b",
-                App().settings.get_enum("shuffle") != Shuffle.NONE)
+            return App().settings.get_value("shuffle")
         elif property_name in ["Rate", "MinimumRate", "MaximumRate"]:
             return GLib.Variant("d", 1.0)
         elif property_name == "Identity":
@@ -336,10 +331,7 @@ class MPRIS(Server):
         if property_name == "Volume":
             App().player.set_volume(new_value)
         elif property_name == "Shuffle":
-            if new_value is True:
-                App().settings.set_enum("shuffle", self.__shuffle_state)
-            else:
-                App().settings.set_enum("shuffle", Shuffle.NONE)
+            App().settings.set_value("shuffle", GLib.Variant("b", new_value))
         elif property_name == "LoopStatus":
             if new_value == "Playlist":
                 value = Repeat.ALL
@@ -392,44 +384,30 @@ class MPRIS(Server):
                 "/org/mpris/MediaPlayer2/TrackList/NoTrack")}
         else:
             self.__metadata["mpris:trackid"] = self.__track_id
-            if App().player.current_track.id == Type.RADIOS:
-                self.__metadata["xesam:title"] = GLib.Variant(
-                    "s",
-                    App().player.current_track.name)
-                self.__metadata["xesam:artist"] = GLib.Variant(
-                    "as",
-                    [App().player.current_track.radio_name])
-                self.__metadata["xesam:trackNumber"] = GLib.Variant(
-                    "i", 0)
-                self.__metadata["xesam:album"] = GLib.Variant("s", "")
-                self.__metadata["xesam:albumArtist"] = GLib.Variant("as",  [])
-                self.__metadata["mpris:length"] = GLib.Variant("x", 0)
-                self.__metadata["xesam:genre"] = GLib.Variant("as", [])
-            else:
-                track_number = App().player.current_track.number
-                if track_number is None:
-                    track_number = 1
-                self.__metadata["xesam:trackNumber"] = GLib.Variant(
-                    "i",
-                    track_number)
-                self.__metadata["xesam:title"] = GLib.Variant(
-                    "s",
-                    App().player.current_track.name)
-                self.__metadata["xesam:album"] = GLib.Variant(
-                    "s",
-                    App().player.current_track.album.name)
-                self.__metadata["xesam:artist"] = GLib.Variant(
-                    "as",
-                    App().player.current_track.artists)
-                self.__metadata["xesam:albumArtist"] = GLib.Variant(
-                    "as",
-                    App().player.current_track.album_artists)
-                self.__metadata["mpris:length"] = GLib.Variant(
-                    "x",
-                    App().player.current_track.duration * 1000 * 1000)
-                self.__metadata["xesam:genre"] = GLib.Variant(
-                    "as",
-                    App().player.current_track.genres)
+            track_number = App().player.current_track.number
+            if track_number is None:
+                track_number = 1
+            self.__metadata["xesam:trackNumber"] = GLib.Variant(
+                "i",
+                track_number)
+            self.__metadata["xesam:title"] = GLib.Variant(
+                "s",
+                App().player.current_track.name)
+            self.__metadata["xesam:album"] = GLib.Variant(
+                "s",
+                App().player.current_track.album.name)
+            self.__metadata["xesam:artist"] = GLib.Variant(
+                "as",
+                App().player.current_track.artists)
+            self.__metadata["xesam:albumArtist"] = GLib.Variant(
+                "as",
+                App().player.current_track.album_artists)
+            self.__metadata["mpris:length"] = GLib.Variant(
+                "x",
+                App().player.current_track.duration * 1000 * 1000)
+            self.__metadata["xesam:genre"] = GLib.Variant(
+                "as",
+                App().player.current_track.genres)
             self.__metadata["xesam:url"] = GLib.Variant(
                 "s",
                 App().player.current_track.uri)
@@ -437,14 +415,14 @@ class MPRIS(Server):
             self.__metadata["xesam:userRating"] = GLib.Variant(
                 "d",
                 self.__rating / 5)
-            if App().player.current_track.id == Type.RADIOS:
+            if isinstance(App().player.current_track, Radio):
                 cover_path = App().art.get_radio_cache_path(
-                    App().player.current_track.radio_name,
-                    ArtSize.MONSTER, ArtSize.MONSTER)
+                    App().player.current_track.name,
+                    ArtSize.MPRIS, ArtSize.MPRIS)
             else:
                 cover_path = App().art.get_album_cache_path(
                     App().player.current_track.album,
-                    ArtSize.MONSTER, ArtSize.MONSTER)
+                    ArtSize.MPRIS, ArtSize.MPRIS)
             if cover_path is None:
                 cover_path = ""
             self.__metadata["mpris:artUrl"] = GLib.Variant(
@@ -461,14 +439,7 @@ class MPRIS(Server):
                                [])
 
     def __on_shuffle_changed(self, settings, value):
-        shuffle_state = App().settings.get_enum("shuffle")
-        # We only want to remember the last non-NONE shuffle state.
-        if shuffle_state != Shuffle.NONE:
-            self.__shuffle_state = shuffle_state
-        value = GLib.Variant(
-            "b",
-            shuffle_state != Shuffle.NONE)
-        properties = {"Shuffle": GLib.Variant("b", value)}
+        properties = {"Shuffle": App().settings.get_value("shuffle")}
         self.PropertiesChanged(self.__MPRIS_PLAYER_IFACE, properties, [])
 
     def __on_repeat_changed(self, settings, value):
@@ -493,8 +464,6 @@ class MPRIS(Server):
     def __on_current_changed(self, player):
         if App().player.current_track.id is None:
             self.__lollypop_id = 0
-        elif App().player.current_track.id == Type.RADIOS:
-            self.__lollypop_id = App().player.current_track.radio_id
         else:
             self.__lollypop_id = App().player.current_track.id
         # We only need to recalculate a new trackId at song changes.
