@@ -35,7 +35,6 @@ class Discoverer:
         """
             Init discover
         """
-        GstPbutils.pb_utils_init()
         self._discoverer = GstPbutils.Discoverer.new(10 * Gst.SECOND)
 
     def get_info(self, uri):
@@ -448,7 +447,39 @@ class TagReader:
                 continue
             if m.data[0:4] == b"POPM":
                 # Get tag
-                popm = m.data[11]
+                """
+                    Location of rating for common media players:
+                    - Plain POPM is located in m.data[11]
+                    - Media Monkey is located in m.data[19] and
+                      we are searching m.data[10:40] for "no@email"
+                    - WinAMP is located in m.data[28] and we are searching
+                      m.data[10:40] for "rating@winamp.com"
+                    - Windows Media Player is located in m.data[40] and
+                      we are searching m.data[10:40] for
+                      "Windows Media Player 9 Series"
+                """
+                if m.data[10:40].find(b"Windows Media Player 9 Series") >= 0:
+                    location = 40
+                    Logger.debug(
+                        "Rating type: Windows Media Player Location:"
+                        " %s Rating: %s", location, m.data[location])
+                elif m.data[10:40].find(b"rating@winamp.com") >= 0:
+                    location = 28
+                    Logger.debug(
+                        "Rating type: WinAMP Location: %s Rating: %s",
+                        location, m.data[location])
+                elif m.data[10:40].find(b"no@email") >= 0:
+                    location = 19
+                    Logger.debug(
+                        "Rating type: MediaMonkey Location: %s Rating: %s",
+                        location, m.data[location])
+                else:
+                    location = 11
+                    Logger.debug(
+                        "Rating type: none Location: %s Rating: %s",
+                        location, m.data[location])
+
+                popm = m.data[location]
                 if popm == 0:
                     value = 0
                 elif popm == 1:
@@ -459,8 +490,10 @@ class TagReader:
                     value = 3
                 elif popm == 196:
                     value = 4
-                else:
+                elif popm == 255:
                     value = 5
+                else:
+                    value = 0
                 return value
         return 0
 
@@ -588,8 +621,7 @@ class TagReader:
             @param artists as [string]
             @param sortnames as [string]
             @param mb_artist_ids as [string]
-            @return [int]
-            @commit needed
+            @return ([int], [int]): (added artist ids, artist ids)
         """
         artist_ids = []
         added_artist_ids = []
@@ -637,11 +669,10 @@ class TagReader:
         """
             Add genres to db
             @param genres as string
-            @return genre ids as [int]
-            @commit needed
+            @return ([int], [int]): (added genre ids, genre ids)
         """
-        # Get all genre ids
         genre_ids = []
+        added_genre_ids = []
         for genre in genres.split(";"):
             genre = genre.strip()
             if genre != "":
@@ -649,8 +680,9 @@ class TagReader:
                 genre_id = App().genres.get_id(genre)
                 if genre_id is None:
                     genre_id = App().genres.add(genre)
+                    added_genre_ids.append(genre_id)
                 genre_ids.append(genre_id)
-        return genre_ids
+        return (added_genre_ids, genre_ids)
 
     def add_album(self, album_name, mb_album_id, artist_ids,
                   uri, loved, popularity, rate, synced, mtime, storage_type):
