@@ -14,9 +14,9 @@ from gi.repository import Gtk, Gio, GLib
 
 from gettext import gettext as _
 
-from lollypop.pop_appmenu import AppMenuPopover
 from lollypop.pop_devices import DevicesPopover
-from lollypop.define import App, Shuffle, Repeat
+from lollypop.define import App, Repeat, Type
+from lollypop.utils import popup_widget, emit_signal
 from lollypop.progressbar import ButtonProgressBar
 
 
@@ -25,27 +25,28 @@ class ToolbarEnd(Gtk.Bin):
         Toolbar end
     """
 
-    def __init__(self):
+    def __init__(self, window):
         """
             Init toolbar
+            @param window as Window
         """
         Gtk.Bin.__init__(self)
         self.set_hexpand(True)
         self.__search_popover = None
         self.__devices_popover = None
+        self.__app_menu = None
+        self.__playback_menu = None
         self.__timeout_id = None
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/ToolbarEnd.ui")
+        self.__shuffle_menu = builder.get_object("shuffle-menu")
         self.__party_submenu = builder.get_object("party_submenu")
         self.add(builder.get_object("end"))
 
-        # Map some settings to actions, can't use Gio.Settings.create_action()
-        # because API does not support set_enabled()
         self.__shuffle_action = Gio.SimpleAction.new_stateful(
             "shuffle",
-            GLib.VariantType.new("s"),
-            GLib.Variant("s", "none"))
-        self.__shuffle_action.set_state(App().settings.get_value("shuffle"))
+            None,
+            App().settings.get_value("shuffle"))
         self.__shuffle_action.connect("change-state",
                                       self.__on_shuffle_change_state)
         self.__repeat_action = Gio.SimpleAction.new_stateful(
@@ -87,17 +88,7 @@ class ToolbarEnd(Gtk.Bin):
         App().add_action(scrobbling_action)
         App().set_accels_for_action("app.scrobbling", ["<Control><Shift>s"])
 
-        self.__search_button = builder.get_object("search_button")
-
-        search_action = App().lookup_action("search")
-        search_action.connect("activate", self.__on_search_activate)
-
-        self.__list_button = builder.get_object("list_button")
-        self.__list_button.set_property("has-tooltip", True)
-        self.__list_button.connect("query-tooltip",
-                                   self.__on_list_button_query_tooltip)
         self.__home_button = builder.get_object("home_button")
-        App().player.connect("playlist-changed", self.__on_playlist_changed)
         self.__set_shuffle_icon()
 
         button_progress_bar = ButtonProgressBar()
@@ -107,40 +98,21 @@ class ToolbarEnd(Gtk.Bin):
         devices_button = builder.get_object("devices_button")
         self.__devices_popover = DevicesPopover(button_progress_bar)
         self.__devices_popover.connect(
-                "closed", self.__on_popover_closed, devices_button)
+                "hidden", self.__on_menu_hidden, devices_button)
         self.__devices_popover.connect("content-changed",
                                        self.__on_devices_content_changed,
                                        devices_button)
         self.__devices_popover.populate()
         builder.connect_signals(self)
-
-    def set_mini(self, mini):
-        """
-            Set mini mode
-            @param mini as bool
-        """
-        if mini:
-            self.__search_button.hide()
-            self.__list_button.hide()
-            self.__home_button.show()
-        else:
-            self.__search_button.show()
-            self.__list_button.show()
-            self.__home_button.hide()
-
-    def search(self, search):
-        """
-            Search item
-            @param search as str
-        """
-        self.__on_search_button_cancelled()
-        self.__search_popover.set_text(search)
+        window.connect("adaptive-changed", self.__on_adaptive_changed)
+        window.container.connect("can-go-back-changed",
+                                 self.__on_can_go_back_changed)
 
     @property
     def devices_popover(self):
         """
             Get Devices Popover
-            @return AppMenuPopover
+            @return DevicesPopover
         """
         return self.__devices_popover
 
@@ -155,41 +127,12 @@ class ToolbarEnd(Gtk.Bin):
 #######################
 # PROTECTED           #
 #######################
-    def _on_list_button_toggled(self, button):
-        """
-            Show current playback context popover
-            @param button as Gtk.ToggleButton
-        """
-        if not button.get_active():
-            return
-        from lollypop.pop_current import CurrentPopover
-        popover = CurrentPopover()
-        popover.set_relative_to(button)
-        popover.popup()
-        popover.connect("closed", self.__on_popover_closed, button)
-        return True
-
     def _on_home_button_clicked(self, button):
         """
             Go home in adaptive mode
             @param button as Gtk.Button
         """
-        App().window.go_home()
-
-    def _on_search_button_toggled(self, button):
-        """
-            Show search popover
-            @param button as Gtk.ToggleButton
-        """
-        if button.get_active():
-            if self.__search_popover is None:
-                from lollypop.pop_search import SearchPopover
-                self.__search_popover = SearchPopover()
-                self.__search_popover.connect("closed",
-                                              self.__on_popover_closed,
-                                              button)
-            self.__search_popover.set_relative_to(button)
-            self.__search_popover.popup()
+        App().window.container.go_home()
 
     def _on_shuffle_button_toggled(self, button):
         """
@@ -197,9 +140,22 @@ class ToolbarEnd(Gtk.Bin):
            @param button as Gtk.ToggleButton
         """
         if button.get_active():
-            # Create submenu "Configure party mode"
+            if self.__app_menu is not None:
+                emit_signal(self.__app_menu, "hidden", True)
             self.__party_submenu.remove_all()
             self.__init_party_submenu()
+            from lollypop.widgets_menu import MenuBuilder
+            self.__playback_menu = MenuBuilder(self.__shuffle_menu)
+            self.__playback_menu.show()
+            popover = popup_widget(self.__playback_menu, button)
+            if popover is None:
+                self.__playback_menu.connect("hidden",
+                                             self.__on_menu_hidden,
+                                             button)
+            else:
+                popover.connect("hidden", self.__on_menu_hidden, button)
+        elif self.__playback_menu is not None and App().window.is_adaptive:
+            emit_signal(self.__playback_menu, "hidden", True)
 
     def _on_devices_button_toggled(self, button):
         """
@@ -215,12 +171,21 @@ class ToolbarEnd(Gtk.Bin):
            Popup application menu
            @param button as Gtk.ToggleButton
         """
+        from lollypop.menu_application import ApplicationMenu
         if button.get_active():
-            appmenu_popover = AppMenuPopover()
-            appmenu_popover.connect(
-                "closed", self.__on_popover_closed, button)
-            appmenu_popover.set_relative_to(button)
-            appmenu_popover.popup()
+            if self.__playback_menu is not None:
+                emit_signal(self.__playback_menu, "hidden", True)
+            self.__app_menu = ApplicationMenu()
+            self.__app_menu.show()
+            popover = popup_widget(self.__app_menu, button)
+            if popover is None:
+                self.__app_menu.connect("hidden",
+                                        self.__on_menu_hidden,
+                                        button)
+            else:
+                popover.connect("hidden", self.__on_menu_hidden, button)
+        elif self.__app_menu is not None and App().window.is_adaptive:
+            emit_signal(self.__app_menu, "hidden", True)
 
 #######################
 # PRIVATE             #
@@ -232,7 +197,7 @@ class ToolbarEnd(Gtk.Bin):
         def on_change_state(action, value, genre_id):
             action.set_state(value)
             ids = list(App().settings.get_value("party-ids"))
-            genre_ids = App().genres.get_ids()
+            genre_ids = App().genres.get_ids() + [Type.WEB]
             # Select all
             if genre_id is None:
                 # Update others
@@ -245,11 +210,12 @@ class ToolbarEnd(Gtk.Bin):
             elif value:
                 ids.append(genre_id)
             # Party id removed
-            elif ids and len(party_ids) > 1:
+            elif ids and len(ids) > 1:
                 ids.remove(genre_id)
             # Initial value
             else:
-                genre_ids.remove(genre_id)
+                ids = list(genre_ids)
+                ids.remove(genre_id)
             App().settings.set_value("party-ids", GLib.Variant("ai", ids))
             App().player.set_party_ids()
             App().player.set_next()
@@ -266,11 +232,9 @@ class ToolbarEnd(Gtk.Bin):
         App().add_action(action)
         item = Gio.MenuItem.new(_("All genres"), "app.all_party_ids")
         self.__party_submenu.append_item(item)
-        i = 0
-        # Hack, hack, hack
-        submenu_name = _("Next")
-        menu = self.__party_submenu
-        for (genre_id, name, sortname) in App().genres.get():
+        genres = App().genres.get()
+        genres.append((Type.WEB, _("Web"), _("Web")))
+        for (genre_id, name, sortname) in genres:
             in_party_ids = not party_ids or genre_id in party_ids
             action_name = "genre_%s" % genre_id
             action = Gio.SimpleAction.new_stateful(
@@ -281,50 +245,32 @@ class ToolbarEnd(Gtk.Bin):
             App().add_action(action)
             menu_str = name if len(name) < 20 else name[0:20] + "…"
             item = Gio.MenuItem.new(menu_str, "app.%s" % action_name)
-            menu.append_item(item)
-            if i > 10:
-                submenu = Gio.Menu()
-                item = Gio.MenuItem.new(submenu_name, None)
-                submenu_name += " "
-                item.set_submenu(submenu)
-                menu.append_item(item)
-                menu = submenu
-                i = 0
-            i += 1
+            self.__party_submenu.append_item(item)
 
     def __set_shuffle_icon(self):
         """
             Set shuffle icon
         """
-        shuffle = App().settings.get_enum("shuffle")
+        shuffle = App().settings.get_value("shuffle")
         repeat = App().settings.get_enum("repeat")
-        if repeat == Repeat.TRACK:
+        if shuffle:
+            self.__shuffle_button_image.set_from_icon_name(
+                "media-playlist-shuffle-symbolic",
+                Gtk.IconSize.BUTTON)
+        elif repeat == Repeat.TRACK:
             self.__shuffle_button_image.get_style_context().remove_class(
                 "selected")
             self.__shuffle_button_image.set_from_icon_name(
                 "media-playlist-repeat-song-symbolic",
-                Gtk.IconSize.SMALL_TOOLBAR)
-        elif shuffle == Shuffle.NONE:
-            self.__shuffle_button_image.get_style_context().remove_class(
-                "selected")
-            if repeat == Repeat.ALL:
-                self.__shuffle_button_image.set_from_icon_name(
-                    "media-playlist-repeat-symbolic",
-                    Gtk.IconSize.SMALL_TOOLBAR)
-            else:
-                self.__shuffle_button_image.set_from_icon_name(
-                    "media-playlist-consecutive-symbolic",
-                    Gtk.IconSize.SMALL_TOOLBAR)
+                Gtk.IconSize.BUTTON)
+        elif repeat == Repeat.ALL:
+            self.__shuffle_button_image.set_from_icon_name(
+                "media-playlist-repeat-symbolic",
+                Gtk.IconSize.BUTTON)
         else:
             self.__shuffle_button_image.set_from_icon_name(
-                "media-playlist-shuffle-symbolic",
-                Gtk.IconSize.SMALL_TOOLBAR)
-            if shuffle == Shuffle.TRACKS:
-                self.__shuffle_button_image.get_style_context().add_class(
-                    "selected")
-            else:
-                self.__shuffle_button_image.get_style_context().remove_class(
-                    "selected")
+                "media-playlist-consecutive-symbolic",
+                Gtk.IconSize.BUTTON)
 
     def __on_party_mode_change_state(self, action, value):
         """
@@ -386,54 +332,20 @@ class ToolbarEnd(Gtk.Bin):
         """
         self.__set_shuffle_icon()
 
-    def __on_popover_closed(self, popover, button):
+    def __on_menu_hidden(self, menu, hide, button):
         """
-            Restore button state
-            @param popover as Popover
+            Restore button state and reset menus
+            @param menu as MenuWidget
+            @param hide as bool
             @param button as Gtk.Button
         """
+        self.__app_menu = None
+        self.__playback_menu = None
         button.set_active(False)
 
-    def __on_search_activate(self, action, variant):
-        """
-            @param action as Gio.SimpleAction
-            @param variant as GLib.Variant
-        """
-        search = variant.get_string()
-        if self.__search_button.is_visible():
-            self.__search_button.set_active(
-                not self.__search_button.get_active())
-            self.__search_popover.set_search(search)
-
-    def __on_list_button_query_tooltip(self, widget, x, y, keyboard, tooltip):
-        """
-            Show tooltip
-            @param widget as Gtk.Widget
-            @param x as int
-            @param y as int
-            @param keyboard as bool
-            @param tooltip as Gtk.Tooltip
-        """
-        if App().player.queue:
-            widget.set_tooltip_text(_("Queue"))
-        elif App().player.playlist_ids:
-            widget.set_tooltip_text(_("Playing playlists"))
-        else:
-            widget.set_tooltip_text(_("Playing albums"))
-
-    def __on_playlist_changed(self, player):
-        """
-            Update playback button status
-            @param player as Player
-        """
-        if player.albums or player.playlist_ids or player.queue:
-            self.__list_button.set_sensitive(True)
-        else:
-            self.__list_button.set_sensitive(False)
-
     def __on_devices_content_changed(self, popover, count, devices_button):
         """
-            Hide/Show button
+            Show/Hide device button
             @param popover as DevicesPopover
             @param count as int
             @param devices_button as Gtk.ToggleButton
@@ -442,3 +354,25 @@ class ToolbarEnd(Gtk.Bin):
             devices_button.show()
         else:
             devices_button.hide()
+
+    def __on_adaptive_changed(self, window, status):
+        """
+            Show/Hide home button
+            @param window as Window
+            @param status as bool
+        """
+        if status:
+            self.__home_button.show()
+        else:
+            self.__home_button.hide()
+
+    def __on_can_go_back_changed(self, container, back):
+        """
+            Make button sensitive
+            @param container as Container
+            @param back as bool
+        """
+        if back:
+            self.__home_button.set_sensitive(True)
+        else:
+            self.__home_button.set_sensitive(False)
