@@ -509,7 +509,7 @@ def get_icon_name(object_id):
         icon = "media-playlist-shuffle-symbolic"
     elif object_id == Type.LOVED:
         icon = "emblem-favorite-symbolic"
-    elif object_id == Type.NEVER:
+    elif object_id == Type.LITTLE:
         icon = "org.gnome.Lollypop-unplayed-albums-symbolic"
     elif object_id == Type.YEARS:
         icon = "x-office-calendar-symbolic"
@@ -528,21 +528,6 @@ def get_icon_name(object_id):
     return icon
 
 
-def update_button(button, style, icon_size, icon_name):
-    """
-        Update button style
-        @param button as Gtk.Button
-        @param style as str
-        @param icon_size as Gtk.Icon_Size
-        @param icon_name as str
-    """
-    context = button.get_style_context()
-    context.remove_class("menu-button-48")
-    context.remove_class("menu-button")
-    context.add_class(style)
-    button.get_image().set_from_icon_name(icon_name, icon_size)
-
-
 def popup_widget(widget, parent, x=None, y=None):
     """
         Popup menu on widget as x, y
@@ -575,34 +560,6 @@ def popup_widget(widget, parent, x=None, y=None):
         return popover
 
 
-def update_track_indexes(listbox, start_index, end_index):
-    """
-        Update track number from start_index + 1 to end_index
-        start_index is a valid track number
-        @param listbox as Gtk.ListBox
-        @param start_index as int
-        @param end_index as int
-    """
-    if start_index == 0:
-        current_number = 0
-    else:
-        current_number = None
-    children = listbox.get_children()
-    if end_index == -1:
-        end_index = len(children)
-    for album_row in children[start_index:end_index]:
-        for track in album_row.album.tracks:
-            if current_number is None:
-                current_number = track.number
-                continue
-            current_number += 1
-            track.set_number(current_number)
-        # Update widget for revealed albums
-        if album_row.revealed:
-            for track_row in album_row.children:
-                track_row.update_number_label()
-
-
 def is_device(mount):
     """
         True if mount is a Lollypop device
