@@ -12,12 +12,10 @@
 
 from gi.repository import Gtk, GLib
 
-from time import time
 from gettext import gettext as _
 import gc
 
-from lollypop.define import ViewType, App, LoadingState, MARGIN_SMALL, Type
-from lollypop.logger import Logger
+from lollypop.define import ViewType, App, MARGIN_SMALL, Type
 from lollypop.adaptive import AdaptiveView
 from lollypop.helper_signals import SignalsHelper, signals_map
 
@@ -67,7 +65,7 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
         self.__stack.show()
         self.__stack.set_transition_type(Gtk.StackTransitionType.NONE)
 
-        self.connect("destroy", self.__on_destroy)
+        self.connect("destroy", self._on_destroy)
         self.connect("map", self._on_map)
         self.connect("unmap", self._on_unmap)
         self.connect("realize", self._on_realize)
@@ -97,9 +95,20 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             self.add(self.__overlay)
         elif self._view_type & ViewType.SCROLLED:
             self.__viewport.add(self.__stack)
+            if banner is not None:
+                self.__banner = banner
+                self.add(self.__banner)
             self.add(self._scrolled)
         else:
+            if banner is not None:
+                self.__banner = banner
+                self.add(self.__banner)
             self.add(self.__stack)
+        if banner is not None:
+            banner.connect("height-changed", self.__on_banner_height_changed)
+
+    def populate(self):
+        pass
 
     def pause(self):
         pass
@@ -221,13 +230,6 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             self._view_type |= ViewType.ADAPTIVE
         else:
             self._view_type &= ~ViewType.ADAPTIVE
-        if self.__banner is not None:
-            self.__banner.set_view_type(self._view_type)
-            main_widget = self.__stack.get_child_by_name("main")
-            main_widget.set_margin_top(self.__banner.height + MARGIN_SMALL)
-            if self._view_type & ViewType.SCROLLED:
-                self._scrolled.get_vscrollbar().set_margin_top(
-                    self.__banner.height)
         return view_type != self._view_type
 
     def _on_value_changed(self, adj):
@@ -239,7 +241,9 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             self.__banner.set_reveal_child(reveal)
             if reveal:
                 main_widget = self.__stack.get_child_by_name("main")
-                main_widget.set_margin_top(self.__banner.height + MARGIN_SMALL)
+                if main_widget is not None:
+                    main_widget.set_margin_top(self.__banner.height +
+                                               MARGIN_SMALL)
                 if self._view_type & ViewType.SCROLLED:
                     self._scrolled.get_vscrollbar().set_margin_top(
                         self.__banner.height)
@@ -276,15 +280,42 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             Restore scroll position
             @param widget as Gtk.Widget
         """
+        parent = widget.get_parent()
+        if self.__banner is not None and parent is not None:
+            width = parent.get_allocated_width()
+            self.__banner.update_for_width(width)
+            self.__on_banner_height_changed(self.__banner,
+                                            self.__banner.height)
         self._on_adaptive_changed(App().window, App().window.is_adaptive)
         # Wait for stack allocation to restore scrolled position
         if self.__scrolled_position is not None:
             self.__stack.connect("size-allocate",
                                  self.__on_stack_size_allocated)
 
+    def _on_destroy(self, widget):
+        """
+            Clean up widget
+            @param widget as Gtk.Widget
+        """
+        self.__destroyed = True
+        self.__event_controller = None
+        gc.collect()
+
 #######################
 # PRIVATE             #
 #######################
+    def __on_banner_height_changed(self, banner, height):
+        """
+            Update scroll margin
+            @param banner as BannerWidget
+            @param height as int
+        """
+        if self._view_type & ViewType.OVERLAY:
+            main_widget = self.__stack.get_child_by_name("main")
+            main_widget.set_margin_top(height + MARGIN_SMALL)
+            if self._view_type & ViewType.SCROLLED:
+                self._scrolled.get_vscrollbar().set_margin_top(height)
+
     def __on_banner_scroll(self, banner, x, y):
         """
             Pass to scrolled
@@ -315,167 +346,3 @@ class View(AdaptiveView, Gtk.Grid, SignalsHelper):
             self._scrolled.get_vadjustment().set_value(
                 self.__scrolled_position)
             self.__scrolled_position = None
-
-    def __on_destroy(self, widget):
-        """
-            Clean up widget
-            @param widget as Gtk.Widget
-        """
-        self.__destroyed = True
-        gc.collect()
-
-
-class LazyLoadingView(View):
-    """
-        Lazy loading for view
-    """
-
-    def __init__(self, view_type=ViewType.DEFAULT):
-        """
-            Init lazy loading
-            @param view_type as ViewType
-        """
-        View.__init__(self, view_type)
-        self.__loading_state = LoadingState.NONE
-        self._lazy_queue = []
-        self.__priority_queue = []
-        self.__scroll_timeout_id = None
-        self.__lazy_loading_id = None
-        self.__start_time = time()
-
-    def pause(self):
-        """
-            Pause loading
-        """
-        self.__loading_state = LoadingState.ABORTED
-        self.__lazy_loading_id = None
-        if self.__scroll_timeout_id is not None:
-            GLib.source_remove(self.__scroll_timeout_id)
-            self.__scroll_timeout_id = None
-        View.stop(self)
-
-    def stop(self):
-        """
-            Stop loading and clear queue
-        """
-        self.__loading_state = LoadingState.FINISHED
-        self.__lazy_loading_id = None
-        if self.__scroll_timeout_id is not None:
-            GLib.source_remove(self.__scroll_timeout_id)
-            self.__scroll_timeout_id = None
-        self._lazy_queue = []
-        self.__priority_queue = []
-        View.stop(self)
-
-    def lazy_loading(self):
-        """
-            Load the view in a lazy way
-        """
-        # He we keep id just to check we are in current load
-        if self.__lazy_loading_id is None:
-            self.__lazy_loading_id = GLib.idle_add(self.__lazy_loading)
-
-    def set_external_scrolled(self, scrolled):
-        """
-            Set an external scrolled window for loading
-            @param scrolled as Gtk.ScrolledWindow
-        """
-        self._scrolled = scrolled
-        scrolled.get_vadjustment().connect("value-changed",
-                                           self._on_value_changed)
-
-    @property
-    def is_populated(self):
-        """
-            True if populated
-            @return bool
-        """
-        return self.__loading_state == LoadingState.FINISHED
-
-#######################
-# PROTECTED           #
-#######################
-    def _on_map(self, widget):
-        """
-            Restore backup and load
-            @param widget as Gtk.Widget
-        """
-        View._on_map(self, widget)
-        if self.__loading_state == LoadingState.ABORTED and self._lazy_queue:
-            self.lazy_loading()
-
-    def _on_value_changed(self, adj):
-        """
-            Update scroll value and check for lazy queue
-            @param adj as Gtk.Adjustment
-        """
-        View._on_value_changed(self, adj)
-        if not self._lazy_queue:
-            return False
-        if self.__scroll_timeout_id is not None:
-            GLib.source_remove(self.__scroll_timeout_id)
-        self.__scroll_timeout_id = GLib.timeout_add(200, self.__lazy_or_not)
-
-    def _on_populated(self, widget, lazy_loading_id):
-        """
-            Add another album/disc
-            @param widget as AlbumWidget/TracksView
-            @parma lazy_loading_id as int
-        """
-        if lazy_loading_id != self.__lazy_loading_id:
-            return
-        if not widget.is_populated:
-            widget.populate()
-        else:
-            self.__lazy_loading()
-
-#######################
-# PRIVATE             #
-#######################
-    def __lazy_loading(self):
-        """
-            Load the view in a lazy way
-        """
-        widget = None
-        if self.__priority_queue:
-            widget = self.__priority_queue.pop(0)
-            self._lazy_queue.remove(widget)
-        elif self._lazy_queue:
-            widget = self._lazy_queue.pop(0)
-        if widget is not None:
-            widget.connect("populated",
-                           self._on_populated,
-                           self.__lazy_loading_id)
-            # https://gitlab.gnome.org/World/lollypop/issues/1884
-            GLib.idle_add(widget.populate)
-        else:
-            self.__lazy_loading_id = None
-            self.__loading_state = LoadingState.FINISHED
-            Logger.debug("LazyLoadingView::lazy_loading(): %s",
-                         time() - self.__start_time)
-
-    def __is_visible(self, widget):
-        """
-            Is widget visible in scrolled
-            @param widget as Gtk.Widget
-        """
-        widget_alloc = widget.get_allocation()
-        scrolled_alloc = self._scrolled.get_allocation()
-        try:
-            (x, y) = widget.translate_coordinates(self._scrolled, 0, 0)
-            return (y > -widget_alloc.height or y >= 0) and\
-                y < scrolled_alloc.height
-        except:
-            return True
-
-    def __lazy_or_not(self):
-        """
-            Add visible widgets to lazy queue
-        """
-        self.__scroll_timeout_id = None
-        if self.__lazy_loading_id is None:
-            return
-        self.__priority_queue = []
-        for child in self._lazy_queue:
-            if self.__is_visible(child):
-                self.__priority_queue.append(child)
