@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib, Gdk, Gtk, Gio, Pango
+from gi.repository import GLib, Gtk, Gio, Pango
 
 from gettext import gettext as _
 from random import shuffle
@@ -152,8 +152,8 @@ class AlbumsBoxView(FlowBoxView, ViewController, SignalsHelper):
                     child.destroy()
                     break
 
-        if scan_update == ScanUpdate.ADDED and\
-                self._genre_ids[0] != Type.NONE:  # AlbumsLineView
+        if scan_update == ScanUpdate.ADDED and self._genre_ids and\
+                Type.NONE not in self._genre_ids:  # AlbumsLineView
             album_ids = App().window.container.get_view_album_ids(
                                             self._genre_ids,
                                             self._artist_ids)
@@ -179,23 +179,6 @@ class AlbumsBoxView(FlowBoxView, ViewController, SignalsHelper):
         """
         App().window.container.show_view([Type.ALBUM], child.data)
 
-    def _on_primary_press_gesture(self, x, y, event):
-        """
-            Popup tracks menu at position
-            @param x as int
-            @param y as int
-            @param event as Gdk.Event
-        """
-        child = self._box.get_child_at_pos(x, y)
-        if child is None or child.artwork is None:
-            return
-        if event.state & Gdk.ModifierType.CONTROL_MASK:
-            from lollypop.pop_tracks import TracksPopover
-            popover = TracksPopover(child.data)
-            popover.set_relative_to(child.artwork)
-            popover.set_position(Gtk.PositionType.BOTTOM)
-            popover.popup()
-
     def _on_tertiary_press_gesture(self, x, y, event):
         """
             Play albums
@@ -380,13 +363,12 @@ class AlbumsLineView(AlbumsBoxView, HorizontalScrollingHelper):
         AlbumsBoxView._on_adaptive_changed(self, window, status)
         self.__update_label(status)
 
-    def _on_populated(self, widget, lazy_loading_id):
+    def _on_populated(self, widget):
         """
             Update button state
             @param widget as Gtk.Widget
-            @parma lazy_loading_id as int
         """
-        AlbumsBoxView._on_populated(self, widget, lazy_loading_id)
+        AlbumsBoxView._on_populated(self, widget)
         if self.is_populated:
             self._update_buttons()
 
