@@ -302,13 +302,12 @@ class RoundedArtistsRandomView(RoundedArtistsView, HorizontalScrollingHelper):
         RoundedArtistsView._on_adaptive_changed(self, window, status)
         self.__update_label(status)
 
-    def _on_populated(self, widget, lazy_loading_id):
+    def _on_populated(self, widget):
         """
             Update button state
             @param widget as Gtk.Widget
-            @parma lazy_loading_id as int
         """
-        RoundedArtistsView._on_populated(self, widget, lazy_loading_id)
+        RoundedArtistsView._on_populated(self, widget)
         if self.is_populated:
             self._update_buttons()
 
