@@ -39,10 +39,9 @@ class PlaylistsManagerView(FlowBoxView, SignalsHelper):
         self._empty_icon_name = "emblem-documents-symbolic"
         self.__banner = PlaylistsBannerWidget(self)
         self.__banner.show()
-        self.__banner.set_view_type(self._view_type)
         self.add_widget(self._box, self.__banner)
         return [
-                (App().playlists, "playlists-changed", "_on_playlist_changed")
+            (App().playlists, "playlists-changed", "_on_playlist_changed")
         ]
 
     def populate(self):
@@ -59,16 +58,6 @@ class PlaylistsManagerView(FlowBoxView, SignalsHelper):
 
         App().task_helper.run(load, callback=(on_load,))
 
-    def remove_value(self, item_id):
-        """
-            Remove value
-            @param item_id as int
-        """
-        for child in self._box.get_children():
-            if child.data == item_id:
-                child.destroy()
-                break
-
     @property
     def args(self):
         """
