@@ -16,7 +16,7 @@ from gettext import gettext as _
 from urllib.parse import urlparse
 
 from lollypop.define import App, StorageType
-from lollypop.define import Size, ViewType
+from lollypop.define import Size, ViewType, MARGIN_SMALL
 from lollypop.view_albums_list import AlbumsListView
 from lollypop.search import Search
 from lollypop.utils import get_network_available, get_youtube_dl
@@ -41,18 +41,21 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
         Gtk.Bin.__init__(self)
         self.__timeout_id = None
         self.__current_search = ""
+        self.__search_empty = True
         self.__cancellable = Gio.Cancellable()
         self._empty_message = _("Search for artists, albums and tracks")
         self._empty_icon_name = "edit-find-symbolic"
         self.__cancellable = Gio.Cancellable()
         self.__bottom_buttons = Gtk.Grid()
         self.__bottom_buttons.show()
-        self.__bottom_buttons.get_style_context().add_class("linked")
         self.__bottom_buttons.set_property("halign", Gtk.Align.CENTER)
+        self.__bottom_buttons.set_margin_bottom(MARGIN_SMALL)
+        self.__bottom_buttons.get_style_context().add_class("linked")
         self.__local_button = Gtk.RadioButton.new()
         self.__local_button.show()
         self.__local_button.set_property("draw-indicator", False)
         self.__local_button.set_name("local")
+        self.__local_button.get_style_context().add_class("light-button")
         image = Gtk.Image.new_from_icon_name("computer-symbolic",
                                              Gtk.IconSize.BUTTON)
         image.show()
@@ -62,6 +65,7 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
         web_button.show()
         web_button.set_property("draw-indicator", False)
         web_button.set_name("web")
+        web_button.get_style_context().add_class("light-button")
         image = Gtk.Image.new_from_icon_name("goa-panel-symbolic",
                                              Gtk.IconSize.BUTTON)
         image.show()
@@ -98,6 +102,7 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
             Populate search
             in db based on text entry current text
         """
+        self.__search_empty = True
         self.__view.stop()
         self.__view.clear()
         self.cancel()
@@ -206,15 +211,18 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
             @param spotify as SpotifyHelper
             @param album as Album
         """
+        self.__search_empty = False
         self.show_placeholder(False)
-        self.__view.insert_album(album, len(album.tracks) == 1, -1)
+        if len(album.tracks) == 1:
+            self.__view.add_reveal_albums([album])
+        self.__view.insert_album(album, -1)
 
     def _on_search_finished(self, *ignore):
         """
             Stop spinner and show placeholder if not result
         """
         self.__banner.spinner.stop()
-        if not self.__view.albums:
+        if self.__search_empty:
             self.show_placeholder(True, _("No results for this search"))
 
 #######################
@@ -252,13 +260,14 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
             @param result as [(int, Album, bool)]
         """
         if result:
+            self.__search_empty = False
             albums = []
             reveal_albums = []
             for (album, in_tracks) in result:
                 albums.append(album)
                 if in_tracks:
                     reveal_albums.append(album)
-            self.__view.set_reveal(reveal_albums)
+            self.__view.add_reveal_albums(reveal_albums)
             self.__view.populate(albums)
             self.show_placeholder(False)
             self.__banner.play_button.set_sensitive(True)
