@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib, Gtk, Gdk, Gio, Pango, GObject
+from gi.repository import GLib, Gtk, Gio, Pango, GObject
 
 from gettext import gettext as _
 
@@ -67,16 +67,6 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
         """
             Populate tracks lazy
         """
-        def load_disc(items, disc_number, position=0):
-            if items:
-                (widget, tracks) = items.pop(0)
-                self.__add_tracks(widget, tracks, position)
-                position += len(tracks)
-                widget.show()
-                GLib.idle_add(load_disc, items, disc_number, position)
-            else:
-                emit_signal(self, "populated")
-
         self.__init()
         if self.__discs_to_load:
             disc = self.__discs_to_load.pop(0)
@@ -91,7 +81,7 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
                               tracks[:mid_tracks]))
                 items.append((self._tracks_widget_right[disc_number],
                               tracks[mid_tracks:]))
-            load_disc(items, disc_number)
+            self.__load_disc(items, disc_number)
         else:
             self.__populated = True
             emit_signal(self, "populated")
@@ -102,8 +92,8 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
                 label = Gtk.Label.new(text)
                 label.get_style_context().add_class("text-large")
                 label.show()
-                self._tracks_widget_left[-1].add(label)
-                self._tracks_widget_left[-1].show()
+                self.__responsive_widget.insert_row(0)
+                self.__responsive_widget.attach(label, 0, 0, 2, 1)
 
     def append_row(self, track):
         """
@@ -114,7 +104,9 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
         """
         self.__init()
         self.__album.append_track(track)
-        self.__add_tracks(self._tracks_widget_left[-1], [track])
+        for key in self._tracks_widget_left.keys():
+            self.__add_tracks(self._tracks_widget_left[key], [track])
+            return
 
     def append_rows(self, tracks):
         """
@@ -124,7 +116,9 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
         """
         self.__init()
         self.__album.append_tracks(tracks)
-        self.__add_tracks(self._tracks_widget_left[-1], tracks)
+        for key in self._tracks_widget_left.keys():
+            self.__add_tracks(self._tracks_widget_left[key], tracks)
+            return
 
     def get_current_ordinate(self, parent):
         """
@@ -299,8 +293,6 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
             Init main widget
         """
         if self.__responsive_widget is None:
-            if self.__view_type & ViewType.DND:
-                self.connect("key-press-event", self.__on_key_press_event)
             self.__responsive_widget = Gtk.Grid()
             self.__responsive_widget.set_column_spacing(20)
             self.__responsive_widget.set_column_homogeneous(True)
@@ -327,6 +319,22 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
         self._tracks_widget_right[disc_number].connect("activated",
                                                        self._on_activated)
 
+    def __load_disc(self, items, disc_number, position=0):
+        """
+            Load discs
+            @param items as (TrackWidget, [Tracks])
+            @param disc_number as int
+            @param position as int
+        """
+        if items:
+            (widget, tracks) = items.pop(0)
+            self.__add_tracks(widget, tracks, position)
+            position += len(tracks)
+            widget.show()
+            GLib.idle_add(self.__load_disc, items, disc_number, position)
+        else:
+            emit_signal(self, "populated")
+
     def __set_orientation(self, orientation):
         """
             Set columns orientation
@@ -421,18 +429,6 @@ class TracksView(Gtk.Bin, SignalsHelper, SizeAllocationHelper):
         """
         emit_signal(self, "track-removed", row)
 
-    def __on_key_press_event(self, widget, event):
-        """
-            Handle keyboard events (DEL, ...)
-            @param widget as Gtk.Widget
-            @param event as Gdk.EventKey
-        """
-        if event.keyval == Gdk.KEY_Delete:
-            for child in self.children:
-                if child.get_state_flags() & Gtk.StateFlags.SELECTED:
-                    pass
-                    # TODO and remove signal usage
-
     def __on_disc_button_press_event(self, button, event, disc):
         """
             Add disc to playback
