@@ -12,10 +12,9 @@
 
 from lollypop.define import App, Type
 from lollypop.widgets_albums_rounded import RoundedAlbumsWidget
-from lollypop.helper_overlay_genre import OverlayGenreHelper
 
 
-class AlbumsGenreWidget(RoundedAlbumsWidget, OverlayGenreHelper):
+class AlbumsGenreWidget(RoundedAlbumsWidget):
     """
         Genre widget showing cover for 4 albums
     """
@@ -27,7 +26,6 @@ class AlbumsGenreWidget(RoundedAlbumsWidget, OverlayGenreHelper):
             @param view_type as ViewType
             @param font_height as int
         """
-        OverlayGenreHelper.__init__(self)
         self.__font_height = font_height
         name = sortname = App().genres.get_name(genre_id)
         RoundedAlbumsWidget.__init__(self, genre_id, name, sortname, view_type)
@@ -38,10 +36,7 @@ class AlbumsGenreWidget(RoundedAlbumsWidget, OverlayGenreHelper):
             Populate widget content
         """
         if self._artwork is None:
-            self._lock_overlay = False
             RoundedAlbumsWidget.populate(self)
-            self._widget.connect("enter-notify-event", self._on_enter_notify)
-            self._widget.connect("leave-notify-event", self._on_leave_notify)
         else:
             self.set_artwork()
 
@@ -54,6 +49,14 @@ class AlbumsGenreWidget(RoundedAlbumsWidget, OverlayGenreHelper):
         self.set_size_request(self._art_size,
                               self._art_size + self.__font_height)
 
+    @property
+    def artwork_name(self):
+        """
+            Get artwork name
+            return str
+        """
+        return "genre_" + self.name
+
 #######################
 # PROTECTED           #
 #######################
@@ -63,7 +66,3 @@ class AlbumsGenreWidget(RoundedAlbumsWidget, OverlayGenreHelper):
             @return [int]
         """
         return App().albums.get_ids([], [self._data])
-
-#######################
-# PRIVATE             #
-#######################
