@@ -15,7 +15,7 @@ from gi.repository import Gtk, GLib, Pango
 from pickle import load, dump
 from gettext import gettext as _
 
-from lollypop.define import App, ArtSize, MARGIN, ViewType, StorageType
+from lollypop.define import App, ArtSize, MARGIN, ViewType, StorageType, Size
 from lollypop.define import ArtBehaviour, LOLLYPOP_DATA_PATH
 from lollypop.widgets_banner import BannerWidget
 from lollypop.widgets_cover import CoverWidget
@@ -72,9 +72,9 @@ class TodayBannerWidget(BannerWidget, SignalsHelper):
         self.__title_label.set_markup(markup)
         self.__title_label.set_ellipsize(Pango.EllipsizeMode.END)
         self.__title_label.set_xalign(0.0)
+        self.__title_label.set_vexpand(True)
         self.__cover_widget = CoverWidget(self.__album, view_type)
         self.__cover_widget.show()
-        self.__cover_widget.set_vexpand(True)
         self.__play_button = Gtk.Button.new()
         self.__play_button.show()
         image = Gtk.Image.new()
@@ -97,21 +97,19 @@ class TodayBannerWidget(BannerWidget, SignalsHelper):
         grid.set_margin_end(MARGIN)
         self._overlay.add_overlay(grid)
         self._overlay.set_overlay_pass_through(grid, True)
-        self.set_reveal_child(False)
-        self.connect("map", self.__on_map)
         return [
                 (App().art, "album-artwork-changed",
                  "_on_album_artwork_changed")
         ]
 
-    def set_view_type(self, view_type):
+    def update_for_width(self, width):
         """
-            Update widget internals for view_type
-            @param view_type as ViewType
+            Update banner internals for width, call this before showing banner
+            @param width as int
         """
-        BannerWidget.set_view_type(self, view_type)
-        self.__cover_widget.set_view_type(view_type)
-        self.__set_text_height()
+        BannerWidget.update_for_width(self, width)
+        self.__set_artwork()
+        self.__set_internal_size()
 
 #######################
 # PROTECTED           #
@@ -122,15 +120,8 @@ class TodayBannerWidget(BannerWidget, SignalsHelper):
             @param allocation as Gtk.Allocation
         """
         if BannerWidget._handle_width_allocate(self, allocation):
-            App().art_helper.set_album_artwork(
-                    self.__album,
-                    # +100 to prevent resize lag
-                    allocation.width + 100,
-                    ArtSize.BANNER + MARGIN * 2,
-                    self._artwork.get_scale_factor(),
-                    ArtBehaviour.BLUR_HARD |
-                    ArtBehaviour.DARKER,
-                    self._on_artwork)
+            self.__set_artwork()
+            self.__set_internal_size()
 
     def _on_album_artwork_changed(self, art, album_id):
         """
@@ -138,45 +129,46 @@ class TodayBannerWidget(BannerWidget, SignalsHelper):
             @param art as Art
             @param album_id as int
         """
-        if album_id == self.__album.id and App().animations:
-            App().art_helper.set_album_artwork(
-                            self.__album,
-                            # +100 to prevent resize lag
-                            self.get_allocated_width() + 100,
-                            self.height,
-                            self._artwork.get_scale_factor(),
-                            ArtBehaviour.BLUR_HARD |
-                            ArtBehaviour.DARKER,
-                            self._on_artwork)
+        if album_id == self.__album.id:
+            self.__set_artwork()
 
 #######################
 # PRIVATE             #
 #######################
-    def __set_text_height(self):
+    def __set_artwork(self):
         """
-            Set text height
+            Set artwork on banner
         """
+        if App().animations:
+            App().art_helper.set_album_artwork(
+                    self.__album,
+                    # +100 to prevent resize lag
+                    self.width + 100,
+                    self.height,
+                    self._artwork.get_scale_factor(),
+                    ArtBehaviour.BLUR_HARD |
+                    ArtBehaviour.DARKER,
+                    self._on_artwork)
+
+    def __set_internal_size(self):
+        """
+            Set content size based on current width
+        """
+        # Text size
         title_context = self.__title_label.get_style_context()
         for c in title_context.list_classes():
             title_context.remove_class(c)
-        if self._view_type & (ViewType.ADAPTIVE | ViewType.SMALL):
-            self.__title_label.get_style_context().add_class(
-                "text-x-large")
+        if self.width <= Size.SMALL:
+            art_size = ArtSize.SMALL
+            cls = "text-large"
+        elif self.width <= Size.MEDIUM:
+            art_size = ArtSize.MEDIUM
+            cls = "text-x-large"
         else:
-            self.__title_label.get_style_context().add_class(
-                "text-xx-large")
-
-    def __on_map(self, widget):
-        """
-            Show banner
-            @param widget as Gtk.Widget
-        """
-        def show():
-            self.set_transition_duration(500)
-            self.set_reveal_child(True)
-            self.set_transition_duration(250)
-
-        GLib.timeout_add(250, show)
+            art_size = ArtSize.BANNER
+            cls = "text-xx-large"
+        self.__title_label.get_style_context().add_class(cls)
+        self.__cover_widget.set_art_size(art_size)
 
     def __on_play_button_clicked(self, button):
         """
